@@ -17,9 +17,12 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <stdio.h>
-#include <stdint.h>
 #ifndef WORDS_BIGENDIAN
 //#include <byteswap.h>
 #endif
@@ -27,6 +30,8 @@
 #include <time.h>
 #include <unistd.h>
 
+#include "mp4write.h"
+
 enum ATOM_TYPE
 {
     ATOM_STOP = 0 /* end of atoms */ ,
@@ -41,25 +46,37 @@ typedef struct
     void *data;
 } creator_t;
 
-#include "mp4write.h"
-
 mp4config_t mp4config = { 0 };
 
 static FILE *g_fout = NULL;
 
-static inline uint32_t bswap32(uint32_t u32)
+static inline uint32_t be32(uint32_t u32)
 {
 #ifndef WORDS_BIGENDIAN
-    //return __bswap_32(u32);
+#if defined (__GNUC__) && ((__GNUC__ > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 3)))
     return __builtin_bswap32(u32);
+#elif defined (_MSC_VER)
+    return _byteswap_ulong(u32);
+#else
+    return (u32 << 24) | ((u32 << 8) & 0xFF0000) | ((u32 >> 8) & 0xFF00) | (u32 >> 24);
+#endif
+#else
+    return u32;
 #endif
 }
 
-static inline uint16_t bswap16(uint16_t u16)
+static inline uint16_t be16(uint16_t u16)
 {
 #ifndef WORDS_BIGENDIAN
-    //return __bswap_16(u16);
+#if defined (__GNUC__) && ((__GNUC__ > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 8)))
     return __builtin_bswap16(u16);
+#elif defined (_MSC_VER)
+    return _byteswap_ushort(u16);
+#else
+    return (u16 << 8) | (u16 >> 8);
+#endif
+#else
+    return u16;
 #endif
 }
 
@@ -80,13 +97,13 @@ static int stringout(const char *txt)
 
 static int u32out(uint32_t u32)
 {
-    u32 = bswap32(u32);
+    u32 = be32(u32);
     return dataout(&u32, 4);
 }
 
 static int u16out(uint16_t u16)
 {
-    u16 = bswap16(u16);
+    u16 = be16(u16);
     return dataout(&u16, 2);
 }
 
