@@ -25,23 +25,22 @@
 
 #include "frame.h"
 #include "coder.h"
-#include "midside.h"
 #include "channels.h"
 #include "bitstream.h"
 #include "filtbank.h"
 #include "util.h"
 #include "tns.h"
-#include "version.h"
+#include "stereo.h"
 
-#if FAAC_RELEASE
-static char *libfaacName = FAAC_VERSION;
-#else
-static char *libfaacName = FAAC_VERSION ".1 (" __DATE__ ") UNSTABLE";
+#if (defined WIN32 || defined _WIN32 || defined WIN64 || defined _WIN64) && !defined(PACKAGE_VERSION)
+#include "win32_ver.h"
 #endif
+
+static char *libfaacName = PACKAGE_VERSION;
 static char *libCopyright =
-  "FAAC - Freeware Advanced Audio Coder (http://www.audiocoding.com/)\n"
+  "FAAC - Freeware Advanced Audio Coder (http://faac.sourceforge.net/)\n"
   " Copyright (C) 1999,2000,2001  Menno Bakker\n"
-  " Copyright (C) 2002,2003  Krzysztof Nikiel\n"
+  " Copyright (C) 2002,2003,2017  Krzysztof Nikiel\n"
   "This software is based on the ISO MPEG-4 reference source code.\n";
 
 static const psymodellist_t psymodellist[] = {
@@ -117,7 +116,7 @@ int FAACAPI faacEncSetConfiguration(faacEncHandle hpEncoder,
     int i;
     int maxqual = hEncoder->config.outputFormat ? MAXQUALADTS : MAXQUAL;
 
-    hEncoder->config.allowMidside = config->allowMidside;
+    hEncoder->config.jointmode = config->jointmode;
     hEncoder->config.useLfe = config->useLfe;
     hEncoder->config.useTns = config->useTns;
     hEncoder->config.aacObjectType = config->aacObjectType;
@@ -144,10 +143,16 @@ int FAACAPI faacEncSetConfiguration(faacEncHandle hpEncoder,
     if (hEncoder->config.aacObjectType != LOW)
         return 0;
 
+#ifdef DRM
+    config->pnslevel = 0;
+#endif
+
     /* Re-init TNS for new profile */
     TnsInit(hEncoder);
 
     /* Check for correct bitrate */
+    if (!hEncoder->sampleRate || !hEncoder->numChannels)
+        return 0;
     if (config->bitRate > (MaxBitrate(hEncoder->sampleRate) / hEncoder->numChannels))
         config->bitRate = MaxBitrate(hEncoder->sampleRate) / hEncoder->numChannels;
 #if 0
@@ -194,9 +199,16 @@ int FAACAPI faacEncSetConfiguration(faacEncHandle hpEncoder,
 
     hEncoder->config.quantqual = config->quantqual;
 
+    if (config->jointmode == JOINT_MS)
+        config->pnslevel = 0;
+    if (config->pnslevel < 0)
+        config->pnslevel = 0;
+    if (config->pnslevel > 10)
+        config->pnslevel = 10;
+    hEncoder->aacquantCfg.pnslevel = config->pnslevel;
     /* set quantization quality */
     hEncoder->aacquantCfg.quality = config->quantqual;
-    BandLimit(&hEncoder->config.bandWidth,
+    CalcBW(&hEncoder->config.bandWidth,
               hEncoder->sampleRate,
               hEncoder->srInfo,
               &hEncoder->aacquantCfg);
@@ -212,7 +224,7 @@ int FAACAPI faacEncSetConfiguration(faacEncHandle hpEncoder,
 			hEncoder->sampleRate, hEncoder->srInfo->cb_width_long,
 			hEncoder->srInfo->num_cb_long, hEncoder->srInfo->cb_width_short,
 			hEncoder->srInfo->num_cb_short);
-	
+
 	/* load channel_map */
 	for( i = 0; i < MAX_CHANNELS; i++ )
 		hEncoder->config.channel_map[i] = config->channel_map[i];
@@ -256,7 +268,8 @@ faacEncHandle FAACAPI faacEncOpen(unsigned long sampleRate,
     hEncoder->config.copyright = libCopyright;
     hEncoder->config.mpegVersion = MPEG4;
     hEncoder->config.aacObjectType = LOW;
-    hEncoder->config.allowMidside = 1;
+    hEncoder->config.jointmode = JOINT_IS;
+    hEncoder->config.pnslevel = 4;
     hEncoder->config.useLfe = 1;
     hEncoder->config.useTns = 0;
     hEncoder->config.bitRate = 64000;
@@ -282,7 +295,7 @@ faacEncHandle FAACAPI faacEncOpen(unsigned long sampleRate,
     /* find correct sampling rate depending parameters */
     hEncoder->srInfo = &srInfo[hEncoder->sampleRateIdx];
 
-    for (channel = 0; channel < numChannels; channel++) 
+    for (channel = 0; channel < numChannels; channel++)
 	{
         hEncoder->coderInfo[channel].prev_window_shape = SINE_WINDOW;
         hEncoder->coderInfo[channel].window_shape = SINE_WINDOW;
@@ -297,7 +310,7 @@ faacEncHandle FAACAPI faacEncOpen(unsigned long sampleRate,
 
     /* Initialize coder functions */
 	fft_initialize( &hEncoder->fft_tables );
-    
+
 	hEncoder->psymodel->PsyInit(&hEncoder->gpsyInfo, hEncoder->psyInfo, hEncoder->numChannels,
         hEncoder->sampleRate, hEncoder->srInfo->cb_width_long,
         hEncoder->srInfo->num_cb_long, hEncoder->srInfo->cb_width_short,
@@ -324,7 +337,7 @@ int FAACAPI faacEncClose(faacEncHandle hpEncoder)
     fft_terminate(&hEncoder->fft_tables);
 
     /* Free remaining buffer memory */
-    for (channel = 0; channel < hEncoder->numChannels; channel++) 
+    for (channel = 0; channel < hEncoder->numChannels; channel++)
 	{
 		if (hEncoder->sampleBuff[channel])
 			FreeMemory(hEncoder->sampleBuff[channel]);
@@ -337,7 +350,7 @@ int FAACAPI faacEncClose(faacEncHandle hpEncoder)
     }
 
     /* Free handle */
-    if (hEncoder) 
+    if (hEncoder)
 		FreeMemory(hEncoder);
 
     BlocStat();
@@ -368,7 +381,7 @@ int FAACAPI faacEncEncode(faacEncHandle hpEncoder,
     unsigned int numChannels = hEncoder->numChannels;
     unsigned int useLfe = hEncoder->config.useLfe;
     unsigned int useTns = hEncoder->config.useTns;
-    unsigned int allowMidside = hEncoder->config.allowMidside;
+    unsigned int jointmode = hEncoder->config.jointmode;
     unsigned int bandWidth = hEncoder->config.bandWidth;
     unsigned int shortctl = hEncoder->config.shortctl;
     int maxqual = hEncoder->config.outputFormat ? MAXQUALADTS : MAXQUAL;
@@ -388,14 +401,14 @@ int FAACAPI faacEncEncode(faacEncHandle hpEncoder,
     GetChannelInfo(channelInfo, numChannels, useLfe);
 
     /* Update current sample buffers */
-    for (channel = 0; channel < numChannels; channel++) 
+    for (channel = 0; channel < numChannels; channel++)
 	{
 		double *tmp;
 
 
 		if (!hEncoder->sampleBuff[channel])
 			hEncoder->sampleBuff[channel] = (double*)AllocMemory(FRAME_LEN*sizeof(double));
-		
+
 		tmp = hEncoder->sampleBuff[channel];
 
         hEncoder->sampleBuff[channel]		= hEncoder->nextSampleBuff[channel];
@@ -431,7 +444,7 @@ int FAACAPI faacEncEncode(faacEncHandle hpEncoder,
                 case FAAC_INPUT_32BIT:
 					{
 						int32_t *input_channel = (int32_t*)inputBuffer + hEncoder->config.channel_map[channel];
-						
+
 						for (i = 0; i < samples_per_channel; i++)
 						{
 							hEncoder->next3SampleBuff[channel][i] = (1.0/256) * (double)*input_channel;
@@ -466,11 +479,11 @@ int FAACAPI faacEncEncode(faacEncHandle hpEncoder,
 		/* LFE psychoacoustic can run without it */
 		if (!channelInfo[channel].lfe || channelInfo[channel].cpe)
 		{
-			hEncoder->psymodel->PsyBufferUpdate( 
-					&hEncoder->fft_tables, 
-					&hEncoder->gpsyInfo, 
+			hEncoder->psymodel->PsyBufferUpdate(
+					&hEncoder->fft_tables,
+					&hEncoder->gpsyInfo,
 					&hEncoder->psyInfo[channel],
-					hEncoder->next3SampleBuff[channel], 
+					hEncoder->next3SampleBuff[channel],
 					bandWidth,
 					hEncoder->srInfo->cb_width_short,
 					hEncoder->srInfo->num_cb_short);
@@ -526,7 +539,7 @@ int FAACAPI faacEncEncode(faacEncHandle hpEncoder,
                 offset += hEncoder->srInfo->cb_width_short[sb];
             }
             coderInfo[channel].sfb_offset[sb] = offset;
-            BlocGroup(hEncoder->freqBuff[channel], coderInfo + channel, hEncoder->aacquantCfg.max_cbs);
+            BlocGroup(hEncoder->freqBuff[channel], coderInfo + channel, &hEncoder->aacquantCfg);
         } else {
             coderInfo[channel].sfbn = hEncoder->aacquantCfg.max_cbl;
 
@@ -564,12 +577,8 @@ int FAACAPI faacEncEncode(faacEncHandle hpEncoder,
 		}
 	}
 
-    if (allowMidside)
-        MSEncode(coderInfo, channelInfo, hEncoder->freqBuff, numChannels,
-                 (double)hEncoder->aacquantCfg.quality/DEFQUAL);
-    else
-        MSEncode(coderInfo, channelInfo, hEncoder->freqBuff, numChannels,
-                 0.0);
+    AACstereo(coderInfo, channelInfo, hEncoder->freqBuff, numChannels,
+              (double)hEncoder->aacquantCfg.quality/DEFQUAL, jointmode);
 
 #ifdef DRM
     /* loop the quantization until the desired bit-rate is reached */
